==> order-center-domain-2.0.9-CLOUD-DEV-20220701.062946-32-sources.jar: com/tydic/dyc/oc/model/insporder/impl/UocInspOrderModelImpl.java <==
package com.tydic.dyc.oc.model.insporder.impl;

import com.tydic.dyc.base.exception.BaseBusinessException;
import com.tydic.dyc.oc.constants.UocObjNoConstants;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.model.insporder.IUocInspOrderModel;
import com.tydic.dyc.oc.model.insporder.UocInspOrderDo;
import com.tydic.dyc.oc.model.insporder.qrybo.UocInspOrderItemQryBo;
import com.tydic.dyc.oc.model.insporder.qrybo.UocInspOrderQryBo;
import com.tydic.dyc.oc.model.insporder.sub.UocInspOrderItem;
import com.tydic.dyc.oc.repository.UocCommonRepository;
import com.tydic.dyc.oc.repository.UocInspOrderRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 标题:UocInspOrderModelImpl
 * 说明:验收单方法实现
 * 时间:2022/2/25 11:34
 * 作者:罗有
 */

@Service
public class UocInspOrderModelImpl implements IUocInspOrderModel {

    @Autowired
    private UocInspOrderRepository uocInspOrderRepository;
    @Autowired
    private UocCommonRepository uocCommonRepository;

    @Override
    public void createInspOrder(UocInspOrderDo uocInspOrderDo) {
        valDo(uocInspOrderDo);
        uocInspOrderRepository.createInspOrder(uocInspOrderDo);
        uocCommonRepository.addBatchOrderAccessory(uocInspOrderDo.getUocOrderAccessoryList());
    }

    @Override
    public UocInspOrderDo getInspOrderMain(UocInspOrderQryBo uocInspOrderQryBo) {
        if (null == uocInspOrderQryBo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        if (null == uocInspOrderQryBo.getOrderId()) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参订单ID不能为空");
        }
        return uocInspOrderRepository.getInspOrderMain(uocInspOrderQryBo);
    }

    @Override
    public UocInspOrderDo getListInspOrderItem(UocInspOrderItemQryBo uocInspOrderItemQryBo) {
        if (null == uocInspOrderItemQryBo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
//        if (null == uocInspOrderItemQryBo.getOrderId()) {
//            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参订单ID不能为空");
//        }
        return uocInspOrderRepository.getListInspOrderItem(uocInspOrderItemQryBo);
    }

    @Override
    public List<UocInspOrderDo> getListInspOrder(UocInspOrderQryBo uocInspOrderQryBo) {
        if (null == uocInspOrderQryBo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象为空");
        }
//        if (null == uocInspOrderQryBo.getOrderId()) {
//            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参订单ID为空");
//        }
        return uocInspOrderRepository.getListInspOrder(uocInspOrderQryBo);
    }

    @Override
    public UocInspOrderDo getInspOrderNo(UocInspOrderDo uocInspOrderDo) {
        if (null == uocInspOrderDo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        if (null == uocInspOrderDo.getOrderSource()) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参来源不能为空");
        }
        String orderNo = uocCommonRepository.getOrderNoSingle(UocObjNoConstants.ORDER_INSPECTION_NO + "_" + uocInspOrderDo.getOrderSource());
        uocInspOrderDo.setInspOrderNo(orderNo);
        return uocInspOrderDo;
    }

    @Override
    public UocInspOrderDo qryTotalFeeAndCount(UocInspOrderQryBo uocInspOrderQryBo) {
        if (null == uocInspOrderQryBo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        return uocInspOrderRepository.qryTotalFeeAndCount(uocInspOrderQryBo);
    }

    @Override
    public void modifySaleOrderItemReturningCount(UocInspOrderItem uocSaleOrderItem) {
        uocInspOrderRepository.modifySaleOrderItemReturningCount(uocSaleOrderItem);
    }

    private void valDo(UocInspOrderDo uocInspOrderDo) {
        if (null == uocInspOrderDo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        if (null == uocInspOrderDo.getOrderId()) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参订单ID不能为空");
        }
    }

    @Override
    public void modifyInspOrderItemChngingCount(UocInspOrderDo convertInspOrderDo) {
        uocInspOrderRepository.modifyInspOrderItemChngingCount(convertInspOrderDo);
    }

    @Override
    public void modifyItemChngCountRefuse(UocInspOrderDo convertInspOrderDo) {
        uocInspOrderRepository.modifyItemChngCountRefuse(convertInspOrderDo);
    }

    @Override
    public void modifyItemChngCountConfirm(UocInspOrderDo convertInspOrderDo) {
        uocInspOrderRepository.modifyItemChngCountConfirm(convertInspOrderDo);
    }
}

==> order-center-domain-3.0.0-CLOUD-DEV-20250409.072946-169-sources.jar: com/tydic/dyc/oc/model/insporder/impl/UocInspOrderModelImpl.java <==
package com.tydic.dyc.oc.model.insporder.impl;

import com.tydic.dyc.base.exception.BaseBusinessException;
import com.tydic.dyc.oc.constants.UocObjNoConstants;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.model.insporder.IUocInspOrderModel;
import com.tydic.dyc.oc.model.insporder.UocInspOrderDo;
import com.tydic.dyc.oc.model.insporder.qrybo.UocInspOrderItemQryBo;
import com.tydic.dyc.oc.model.insporder.qrybo.UocInspOrderQryBo;
import com.tydic.dyc.oc.model.insporder.sub.UocInspOrderItem;
import com.tydic.dyc.oc.repository.UocCommonRepository;
import com.tydic.dyc.oc.repository.UocInspOrderRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 标题:UocInspOrderModelImpl
 * 说明:验收单方法实现
 * 时间:2022/2/25 11:34
 * 作者:罗有
 */

@Service
public class UocInspOrderModelImpl implements IUocInspOrderModel {

    @Autowired
    private UocInspOrderRepository uocInspOrderRepository;
    @Autowired
    private UocCommonRepository uocCommonRepository;

    @Override
    public void createInspOrder(UocInspOrderDo uocInspOrderDo) {
        valDo(uocInspOrderDo);
        uocInspOrderRepository.createInspOrder(uocInspOrderDo);
        uocCommonRepository.addBatchOrderAccessory(uocInspOrderDo.getUocOrderAccessoryList());
    }

    @Override
    public UocInspOrderDo getInspOrderMain(UocInspOrderQryBo uocInspOrderQryBo) {
        if (null == uocInspOrderQryBo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        if (null == uocInspOrderQryBo.getOrderId()) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参订单ID不能为空");
        }
        return uocInspOrderRepository.getInspOrderMain(uocInspOrderQryBo);
    }

    @Override
    public UocInspOrderDo getListInspOrderItem(UocInspOrderItemQryBo uocInspOrderItemQryBo) {
        if (null == uocInspOrderItemQryBo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
//        if (null == uocInspOrderItemQryBo.getOrderId()) {
//            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参订单ID不能为空");
//        }
        return uocInspOrderRepository.getListInspOrderItem(uocInspOrderItemQryBo);
    }

    @Override
    public List<UocInspOrderDo> getListInspOrder(UocInspOrderQryBo uocInspOrderQryBo) {
        if (null == uocInspOrderQryBo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象为空");
        }
//        if (null == uocInspOrderQryBo.getOrderId()) {
//            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参订单ID为空");
//        }
        return uocInspOrderRepository.getListInspOrder(uocInspOrderQryBo);
    }

    @Override
    public UocInspOrderDo getInspOrderNo(UocInspOrderDo uocInspOrderDo) {
        if (null == uocInspOrderDo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        if (null == uocInspOrderDo.getOrderSource()) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参来源不能为空");
        }
        String orderNo = uocCommonRepository.getOrderNoSingle(UocObjNoConstants.ORDER_INSPECTION_NO + "_" + uocInspOrderDo.getOrderSource(), uocInspOrderDo.getSysTenantId());
        uocInspOrderDo.setInspOrderNo(orderNo);
        return uocInspOrderDo;
    }

    @Override
    public UocInspOrderDo qryTotalFeeAndCount(UocInspOrderQryBo uocInspOrderQryBo) {
        if (null == uocInspOrderQryBo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        return uocInspOrderRepository.qryTotalFeeAndCount(uocInspOrderQryBo);
    }

    @Override
    public void modifySaleOrderItemReturningCount(UocInspOrderItem uocSaleOrderItem) {
        uocInspOrderRepository.modifySaleOrderItemReturningCount(uocSaleOrderItem);
    }

    private void valDo(UocInspOrderDo uocInspOrderDo) {
        if (null == uocInspOrderDo) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        if (null == uocInspOrderDo.getOrderId()) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_METHOD_ARG_EMPTY_ERROR, "入参订单ID不能为空");
        }
    }

    @Override
    public void modifyInspOrderItemChngingCount(UocInspOrderDo convertInspOrderDo) {
        uocInspOrderRepository.modifyInspOrderItemChngingCount(convertInspOrderDo);
    }

    @Override
    public void modifyItemChngCountRefuse(UocInspOrderDo convertInspOrderDo) {
        uocInspOrderRepository.modifyItemChngCountRefuse(convertInspOrderDo);
    }

    @Override
    public void modifyItemChngCountConfirm(UocInspOrderDo convertInspOrderDo) {
        uocInspOrderRepository.modifyItemChngCountConfirm(convertInspOrderDo);
    }

    @Override
    public void modifyBatchItemInspConfirm(UocInspOrderDo convertInspOrderDo) {
        uocInspOrderRepository.modifyBatchItemInspConfirm(convertInspOrderDo);
    }
}
